@@ -30,7 +30,7 @@ GetPosteriorStateSamples <- function(bsts.model) {
   # discarding burn-in samples (=> 900 x 2 x 365)
   burn <- SuggestBurn(0.1, bsts.model)
   assert_that(burn > 0)
-  state.contributions <- bsts.model$state.contributions[-(1 : burn), , ,
+  state.contributions <- bsts.model$state.contributions[-seq_len(burn), , ,
                                                         drop = FALSE]
 
   # Sum across states, call it 'state.samples' (=> 900 x 365)
@@ -57,7 +57,7 @@ ComputeResponseTrajectories <- function(bsts.model) {
   # Get observation noise standard deviation samples
   burn <- SuggestBurn(0.1, bsts.model)
   assert_that(burn > 0)
-  sigma.obs <- bsts.model$sigma.obs[-(1 : burn)]  # e.g., 900
+  sigma.obs <- bsts.model$sigma.obs[-seq_len(burn)]  # e.g., 900
 
   # Sample from the posterior predictive density over data
   n.samples <- dim(state.samples)[1]  # e.g., 900 x 365
@@ -135,9 +135,9 @@ ComputeCumulativePredictions <- function(y.samples, point.pred, y,
   # post-period.
 
   # Compute posterior mean
-  is.post.period <- (1 : length(y)) >= post.period.begin
-  cum.pred.mean.pre <- cumsum.na.rm(as.vector(y)[1 : (post.period.begin - 1)])
-  non.na.indices <- which(!is.na(cum.pred.mean.pre[1:(post.period.begin - 1)]))
+  is.post.period <- seq_along(y) >= post.period.begin
+  cum.pred.mean.pre <- cumsum.na.rm(as.vector(y)[!is.post.period])
+  non.na.indices <- which(!is.na(cum.pred.mean.pre))
   assert_that(length(non.na.indices) > 0)
   last.non.na.index <- max(non.na.indices)
   cum.pred.mean.post <- cumsum(point.pred$point.pred[is.post.period]) +
@@ -146,7 +146,7 @@ ComputeCumulativePredictions <- function(y.samples, point.pred, y,
 
   # Check for overflow
   assert_that(identical(which(is.na(cum.pred.mean)),
-                        which(is.na(y[1:(post.period.begin - 1)]))),
+                        which(is.na(y[!is.post.period]))),
               msg = "unexpected NA found in cum.pred.mean")
 
   # Compute posterior interval
@@ -245,7 +245,8 @@ CompileSummaryTable <- function(y.post, y.samples.post,
                                    prob.upper)),
       AbsEffect.sd = c(sd(rowMeans(y.repmat.post - y.samples.post)),
                        sd(rowSums(y.repmat.post - y.samples.post))))
-  summary <- dplyr::mutate(summary, RelEffect = AbsEffect / Pred,
+  summary <- dplyr::mutate(summary,
+                           RelEffect = AbsEffect / Pred,
                            RelEffect.lower = AbsEffect.lower / Pred,
                            RelEffect.upper = AbsEffect.upper / Pred,
                            RelEffect.sd = AbsEffect.sd / Pred)
@@ -333,7 +334,7 @@ InterpretSummaryTable <- function(summary, digits = 2L) {
   # Summarize relative numbers (in which case row [1] = row [2])
   stmt <- paste0(stmt, "\n\nThe above results are given in terms of ",
                  "absolute numbers. In relative terms, the response variable ",
-                 "showed ", if (pos) "an increase of " else "a decrease of",
+                 "showed ", if (pos) "an increase of " else "a decrease of ",
                  rel.effect[1], ". The ", ci.coverage, " interval of this ",
                  "percentage is [", rel.effect.lower[1], ", ",
                  rel.effect.upper[1], "].")
@@ -418,7 +419,7 @@ AssertCumulativePredictionsAreConsistent <- function(cum.pred, post.period,
   AssertCumulativePredictionIsConsistent <- function(cum.pred.col,
                                                      summary.entry,
                                                      description) {
-    non.na.indices <- which(!is.na(cum.pred.col[1:(post.period[1] - 1)]))
+    non.na.indices <- which(!is.na(cum.pred.col[seq_len(post.period[1] - 1)]))
     assert_that(length(non.na.indices) > 0)
     last.non.na.index <- max(non.na.indices)
     assert_that(
@@ -611,7 +612,7 @@ CompileNaInferences <- function(y.model) {
             "cum.pred", "cum.pred.lower", "cum.pred.upper",
             "point.effect", "point.effect.lower", "point.effect.upper",
             "cum.effect", "cum.effect.lower", "cum.effect.upper")
-  na.series <- matrix(as.numeric(NA), nrow = length(y.model), ncol = 12)
+  na.series <- matrix(NA_real_, nrow = length(y.model), ncol = 12)
   na.series <- zoo(na.series, time(y.model))
   names(na.series) <- vars
 
